==> dnet-oai-modular-ui-0.0.1.3-20170110.101441-82-sources.jar: eu/dnetlib/functionality/modular/ui/oai/OAIInternalController.java <==
package eu.dnetlib.functionality.modular.ui.oai;

import java.io.IOException;
import java.io.StringReader;
import java.io.StringWriter;
import java.lang.reflect.Type;
import java.util.Collection;
import java.util.List;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.commons.io.IOUtils;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;

import com.google.common.base.Function;
import com.google.common.collect.ArrayListMultimap;
import com.google.common.collect.ImmutableList;
import com.google.common.collect.ImmutableSet;
import com.google.common.collect.Iterables;
import com.google.common.collect.Lists;
import com.google.common.collect.Multimap;
import com.google.gson.Gson;
import com.google.gson.reflect.TypeToken;

import eu.dnetlib.data.information.oai.publisher.conf.OAIConfigurationExistReader;
import eu.dnetlib.data.information.oai.publisher.conf.OAIConfigurationWriter;
import eu.dnetlib.data.information.oai.publisher.conf.sync.SchedulableOAIStoreAllCounters;
import eu.dnetlib.data.information.oai.publisher.info.MDFInfo;
import eu.dnetlib.data.information.oai.publisher.info.SetInfo;
import eu.dnetlib.data.information.oai.publisher.store.MongoPublisherStoreDAO;
import eu.dnetlib.data.information.oai.publisher.store.PublisherField;
import eu.dnetlib.data.information.oai.publisher.store.sync.SchedulableContentSynchronizer;

@Controller
public class OAIInternalController {

	@Resource
	private OAIConfigurationExistReader configuration;
	@Resource
	private OAIConfigurationWriter configurationWriter;
	@Resource
	private SchedulableContentSynchronizer oaiContentSynchronizer;
	@Resource
	private MongoPublisherStoreDAO mongoPublisherStoreDAO;
	@Resource
	private SchedulableOAIStoreAllCounters oaiSetCounter;

	private static final Log log = LogFactory.getLog(OAIInternalController.class);

	@RequestMapping(value = "/ui/getExportMDFs.do")
	public void getExportMDFs(final HttpServletResponse response) throws Exception {
		List<MDFInfo> exportMDFs = configuration.getMetadataFormatInfo();
		String json = new Gson().toJson(exportMDFs);
		IOUtils.copy(new StringReader(json), response.getOutputStream());
	}

	@RequestMapping(value = "/ui/getSourceMDFs.do")
	public void getSourceMDFs(final HttpServletResponse response) throws Exception {
		List<MDFInfo> exportMDFs = configuration.getMetadataFormatInfo();
		List<MDFInfo> srcMDFList = Lists.transform(exportMDFs, new Function<MDFInfo, MDFInfo>() {

			@Override
			public MDFInfo apply(final MDFInfo mdf) {
				MDFInfo srcOnly = new MDFInfo();
				srcOnly.setSourceFormatName(mdf.getSourceFormatName());
				srcOnly.setSourceFormatLayout(mdf.getSourceFormatLayout());
				srcOnly.setSourceFormatInterpretation(mdf.getSourceFormatInterpretation());
				return srcOnly;
			}
		});
		// using ImmutableSet to remove duplicates
		ImmutableList<MDFInfo> srcMDFs = ImmutableSet.copyOf(srcMDFList).asList();
		String json = new Gson().toJson(srcMDFs);
		log.info(json);
		IOUtils.copy(new StringReader(json), response.getOutputStream());
	}

	@RequestMapping(value = "/ui/getSetSpecs.do")
	public void getSetSpecs(final HttpServletResponse response) throws Exception {
		String json = new Gson().toJson(configuration.getSetSpecs());
		IOUtils.copy(new StringReader(json), response.getOutputStream());
	}

	@RequestMapping(value = "/ui/getMetadataFormat.do")
	public void getMetadataFormat(final HttpServletResponse response, @RequestParam(value = "mdPrefix", required = true) final String mdPrefix)
			throws Exception {
		MDFInfo mdf = this.configuration.getMetadataFormatInfo(mdPrefix);
		String mdfJson = new Gson().toJson(mdf);
		IOUtils.copy(new StringReader(mdfJson), response.getOutputStream());
	}

	@RequestMapping(value = "/ui/saveMetadataFormat.do", method = RequestMethod.POST)
	public void saveMetadataFormat(final HttpServletResponse response,
			final HttpServletRequest request,
			@RequestParam(value = "mdPrefix", required = true) final String mdPrefix) throws Exception {

		MDFInfo update = new Gson().fromJson(request.getReader(), MDFInfo.class);
		if (update.getBaseQuery() == null) {
			update.setBaseQuery("");
		}
		if (update.getTransformationRuleID() == null) {
			update.setTransformationRuleID("");
		}
		log.info("Update to object" + update);
		boolean result = false;
		if (this.configuration.getMetadataFormatInfo(mdPrefix) != null) {
			log.info("UPDATING mdPrefix = " + mdPrefix);
			result = this.configurationWriter.updateMetadataFormat(mdPrefix, update);
		} else {
			// ADD NEW mdf
			log.info("CREATING new mdPrefix = " + mdPrefix);
			result = this.configurationWriter.addMetadataFormat(update);
		}
		response.getWriter().print(result);
	}

	@RequestMapping(value = "/ui/deleteMetadataFormat.do")
	public void deleteMetadataFormat(final HttpServletResponse response, @RequestParam(value = "mdPrefix", required = true) final String mdPrefix)
			throws Exception {
		boolean result = this.configurationWriter.deleteMetadataFormat(mdPrefix);
		response.getWriter().print(result);
	}

	@RequestMapping(value = "/ui/showSetDetails.do")
	public void showSetDetails(final HttpServletResponse response, @RequestParam(value = "setSpec", required = true) final String setSpec) throws Exception {
		SetInfo set = this.configuration.getSetInfo(setSpec);
		String json = new Gson().toJson(set);
		IOUtils.copy(new StringReader(json), response.getOutputStream());
	}

	@RequestMapping(value = "/ui/saveOAISet.do", method = RequestMethod.POST)
	public void saveOAISet(final HttpServletResponse response,
			final HttpServletRequest request,
			@RequestParam(value = "setSpec", required = true) final String setSpec) throws Exception {

		log.info("setSpec = " + setSpec);
		SetInfo update = new Gson().fromJson(request.getReader(), SetInfo.class);
		log.info("Update to object" + update);
		boolean result = false;
		if (this.configuration.getSetInfo(setSpec) != null) {
			log.info("UPDATING set = " + setSpec);
			result = this.configurationWriter.updateOAISet(setSpec, update);
		} else {
			// ADD NEW mdf
			log.info("CREATING new OAIset = " + setSpec);
			result = this.configurationWriter.addOAISet(update);
		}
		response.getWriter().print(result);
	}

	@RequestMapping(value = "/ui/deleteOAISet.do")
	public void deleteOAISet(final HttpServletResponse response, @RequestParam(value = "setSpec", required = true) final String setSpec) throws Exception {
		boolean result = this.configurationWriter.deleteOAISet(setSpec);
		response.getWriter().print(result);
	}

	@RequestMapping(value = "/ui/showIndices.do")
	public void showIndices(final HttpServletResponse response,
			@RequestParam(value = "format", required = true) final String format,
			@RequestParam(value = "layout", required = true) final String layout,
			@RequestParam(value = "interpretation", required = true) final String interpretation) throws Exception {

		List<PublisherField> fields = this.configuration.getFields(format, interpretation, layout);

		// Need to iterate over the values to build an object otherwise angularjs does not allow me to edit the content!
		// See http://stackoverflow.com/questions/13714884/difficulty-with-ng-model-ng-repeat-and-inputs
		List<OAIIndex> indices = Lists.newArrayList();
		for (PublisherField field : fields) {
			Collection<String> paths = field.getSources().get(format + "-" + layout + "-" + interpretation);
			List<IndexPath> pathList = Lists.newArrayList();
			for (String p : paths) {
				pathList.add(new IndexPath(p));
			}
			OAIIndex idx = new OAIIndex();
			idx.setRepeatable(field.isRepeatable());
			idx.setName(field.getFieldName());
			idx.setPaths(pathList);
			indices.add(idx);
		}
		String json = new Gson().toJson(indices);
		log.info("The map of indices: " + json);
		IOUtils.copy(new StringReader(json), response.getOutputStream());
	}

	@RequestMapping(value = "/ui/saveIndices.do", method = RequestMethod.POST)
	public void saveIndices(final HttpServletResponse response,
			final HttpServletRequest request,
			@RequestParam(value = "format", required = true) final String format,
			@RequestParam(value = "layout", required = true) final String layout,
			@RequestParam(value = "interpretation", required = true) final String interpretation) throws Exception {

		StringWriter sw = new StringWriter();
		IOUtils.copy(request.getInputStream(), sw);
		Type collectionType = new TypeToken<List<OAIIndex>>() {}.getType();
		List<OAIIndex> indexes = new Gson().fromJson(sw.toString(), collectionType);
		final String mdformatKey = format + "-" + layout + "-" + interpretation;
		List<PublisherField> updatedIndices = Lists.transform(indexes, new Function<OAIIndex, PublisherField>() {

			@Override
			public PublisherField apply(final OAIIndex oaiIndex) {
				PublisherField f = new PublisherField();
				f.setFieldName(oaiIndex.getName());
				f.setRepeatable(oaiIndex.isRepeatable());
				Multimap<String, String> paths = ArrayListMultimap.create();
				for (IndexPath path : oaiIndex.getPaths()) {
					paths.put(mdformatKey, path.getPath());
				}
				f.setSources(paths);
				return f;
			}

		});

		log.info("Updating indices" + indexes);
		boolean result = this.configurationWriter.updateIndices(format, layout, interpretation, updatedIndices);
		response.getWriter().print(result);
	}

	@RequestMapping(value = "/ui/saveNewIndex.do")
	public void saveNewIndex(final HttpServletResponse response,
			@RequestParam(value = "format", required = true) final String format,
			@RequestParam(value = "layout", required = true) final String layout,
			@RequestParam(value = "interpretation", required = true) final String interpretation,
			@RequestParam(value = "indexName", required = true) final String indexName,
			@RequestParam(value = "repeatable", required = true) final boolean repeatable,
			@RequestParam(value = "paths", required = true) final String paths) throws Exception {

		String[] thePaths = paths.split(",");
		boolean result = this.configurationWriter.addNewIndex(format, layout, interpretation, indexName, repeatable, thePaths);
		response.getWriter().print(result);
	}

	@RequestMapping(value = "/ui/saveNewPathIndex.do")
	public void saveNewPathIndex(final HttpServletResponse response,
			@RequestParam(value = "format", required = true) final String format,
			@RequestParam(value = "layout", required = true) final String layout,
			@RequestParam(value = "interpretation", required = true) final String interpretation,
			@RequestParam(value = "indexName", required = true) final String indexName,
			@RequestParam(value = "newPath", required = true) final String newPath) throws Exception {

		List<PublisherField> fields = this.configurationWriter.getConfiguration().getFields(format, interpretation, layout);
		Iterable<PublisherField> updated = Iterables.transform(fields, new Function<PublisherField, PublisherField>() {

			@Override
			public PublisherField apply(final PublisherField field) {
				if (field.getFieldName().equals(indexName)) {
					field.getSources().get(format + "-" + layout + "-" + interpretation).add(newPath);
				}
				return field;
			}
		});
		boolean result = this.configurationWriter.updateIndices(format, layout, interpretation, Lists.newArrayList(updated));
		response.getWriter().print(result);
	}

	@RequestMapping(value = "/ui/getTransformationRules.do")
	public void getTransformationRules(final HttpServletResponse response) throws IOException {

		final String query = "for $x in collection('/db/DRIVER/TransformationRuleDSResources/TransformationRuleDSResourceType')"
				+ " return concat($x//RESOURCE_IDENTIFIER/@value/string(), ':-:', $x//CONFIGURATION//TITLE)";
		Iterable<TDSRule> rules = this.configuration.getQueryExecutor().query(TDSRule.class, query);
		String json = new Gson().toJson(Lists.newArrayList(rules));
		IOUtils.copy(new StringReader(json), response.getOutputStream());
	}

	@RequestMapping(value = "/ui/synchContent.do")
	public void synchronizeContent(final HttpServletResponse response) throws IOException {
		boolean enabled = this.oaiContentSynchronizer.isEnabled();
		if (!enabled) {
			this.oaiContentSynchronizer.setEnabled(true);
		}
		this.oaiContentSynchronizer.execute();
		this.oaiContentSynchronizer.setEnabled(enabled);
		response.getWriter().print(true);
	}

	@RequestMapping(value = "/ui/updateSetCounters.do")
	public void updateSetCounters(final HttpServletResponse response) throws IOException {

		boolean enabled = this.oaiSetCounter.isEnabled();
		if (!enabled) {
			this.oaiSetCounter.setEnabled(true);
		}
		this.oaiSetCounter.execute();
		this.oaiSetCounter.setEnabled(enabled);
		response.getWriter().print(true);
	}

	@RequestMapping(value = "/ui/ensureIndexes.do")
	public void ensureIndexes(final HttpServletResponse response) throws IOException {
		this.mongoPublisherStoreDAO.ensureIndex(3);
		response.getWriter().print(true);
	}

	public SchedulableContentSynchronizer getOaiContentSynchronizer() {
		return oaiContentSynchronizer;
	}

	public void setOaiContentSynchronizer(final SchedulableContentSynchronizer oaiContentSynchronizer) {
		this.oaiContentSynchronizer = oaiContentSynchronizer;
	}

	public MongoPublisherStoreDAO getMongoPublisherStoreDAO() {
		return mongoPublisherStoreDAO;
	}

	public void setMongoPublisherStoreDAO(final MongoPublisherStoreDAO mongoPublisherStoreDAO) {
		this.mongoPublisherStoreDAO = mongoPublisherStoreDAO;
	}

	public SchedulableOAIStoreAllCounters getOaiSetCounter() {
		return oaiSetCounter;
	}

	public void setOaiSetCounter(final SchedulableOAIStoreAllCounters oaiSetCounter) {
		this.oaiSetCounter = oaiSetCounter;
	}

}

==> dnet-oai-modular-ui-1.0.0-20150519.103516-12-sources.jar: eu/dnetlib/functionality/modular/ui/oai/OAIInternalController.java <==
package eu.dnetlib.functionality.modular.ui.oai;

import java.io.IOException;
import java.io.StringReader;
import java.io.StringWriter;
import java.lang.reflect.Type;
import java.util.Collection;
import java.util.List;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.commons.io.IOUtils;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;

import com.google.common.base.Function;
import com.google.common.collect.ArrayListMultimap;
import com.google.common.collect.ImmutableList;
import com.google.common.collect.ImmutableSet;
import com.google.common.collect.Iterables;
import com.google.common.collect.Lists;
import com.google.common.collect.Multimap;
import com.google.gson.Gson;
import com.google.gson.reflect.TypeToken;

import eu.dnetlib.data.information.oai.publisher.PublisherField;
import eu.dnetlib.data.information.oai.publisher.conf.OAIConfigurationExistReader;
import eu.dnetlib.data.information.oai.publisher.conf.OAIConfigurationWriter;
import eu.dnetlib.data.information.oai.publisher.info.MDFInfo;
import eu.dnetlib.data.information.oai.publisher.info.SetInfo;

@Controller
public class OAIInternalController {

	private static final Log log = LogFactory.getLog(OAIInternalController.class); // NOPMD by marko on 11/24/08 5:02 PM

	@Resource
	private OAIConfigurationExistReader configuration;
	@Resource
	private OAIConfigurationWriter configurationWriter;

	@RequestMapping(value = "/ui/getExportMDFs.do")
	public void getExportMDFs(final HttpServletResponse response) throws Exception {
		List<MDFInfo> exportMDFs = configuration.getMetadataFormatInfo();
		String json = new Gson().toJson(exportMDFs);
		IOUtils.copy(new StringReader(json), response.getOutputStream());
	}

	@RequestMapping(value = "/ui/getSourceMDFs.do")
	public void getSourceMDFs(final HttpServletResponse response) throws Exception {
		List<MDFInfo> exportMDFs = configuration.getMetadataFormatInfo();
		List<MDFInfo> srcMDFList = Lists.transform(exportMDFs, new Function<MDFInfo, MDFInfo>() {

			@Override
			public MDFInfo apply(final MDFInfo mdf) {
				MDFInfo srcOnly = new MDFInfo();
				srcOnly.setSourceFormatName(mdf.getSourceFormatName());
				srcOnly.setSourceFormatLayout(mdf.getSourceFormatLayout());
				srcOnly.setSourceFormatInterpretation(mdf.getSourceFormatInterpretation());
				return srcOnly;
			}
		});
		// using ImmutableSet to remove duplicates
		ImmutableList<MDFInfo> srcMDFs = ImmutableSet.copyOf(srcMDFList).asList();
		String json = new Gson().toJson(srcMDFs);
		log.info(json);
		IOUtils.copy(new StringReader(json), response.getOutputStream());
	}

	@RequestMapping(value = "/ui/getSetSpecs.do")
	public void getSetSpecs(final HttpServletResponse response) throws Exception {
		String json = new Gson().toJson(configuration.getSetSpecs());
		IOUtils.copy(new StringReader(json), response.getOutputStream());
	}

	@RequestMapping(value = "/ui/getMetadataFormat.do")
	public void getMetadataFormat(final HttpServletResponse response, @RequestParam(value = "mdPrefix", required = true) final String mdPrefix)
			throws Exception {
		MDFInfo mdf = this.configuration.getMetadataFormatInfo(mdPrefix);
		String mdfJson = new Gson().toJson(mdf);
		IOUtils.copy(new StringReader(mdfJson), response.getOutputStream());
	}

	@RequestMapping(value = "/ui/saveMetadataFormat.do", method = RequestMethod.POST)
	public void saveMetadataFormat(final HttpServletResponse response,
			final HttpServletRequest request,
			@RequestParam(value = "mdPrefix", required = true) final String mdPrefix) throws Exception {

		MDFInfo update = new Gson().fromJson(request.getReader(), MDFInfo.class);
		if (update.getBaseQuery() == null) {
			update.setBaseQuery("");
		}
		if (update.getTransformationRuleID() == null) {
			update.setTransformationRuleID("");
		}
		log.info("Update to object" + update);
		boolean result = false;
		if (this.configuration.getMetadataFormatInfo(mdPrefix) != null) {
			log.info("UPDATING mdPrefix = " + mdPrefix);
			result = this.configurationWriter.updateMetadataFormat(mdPrefix, update);
		} else {
			// ADD NEW mdf
			log.info("CREATING new mdPrefix = " + mdPrefix);
			result = this.configurationWriter.addMetadataFormat(update);
		}
		response.getWriter().print(result);
	}

	@RequestMapping(value = "/ui/deleteMetadataFormat.do")
	public void deleteMetadataFormat(final HttpServletResponse response, @RequestParam(value = "mdPrefix", required = true) final String mdPrefix)
			throws Exception {
		boolean result = this.configurationWriter.deleteMetadataFormat(mdPrefix);
		response.getWriter().print(result);
	}

	@RequestMapping(value = "/ui/showSetDetails.do")
	public void showSetDetails(final HttpServletResponse response, @RequestParam(value = "setSpec", required = true) final String setSpec) throws Exception {
		SetInfo set = this.configuration.getSetInfo(setSpec);
		String json = new Gson().toJson(set);
		IOUtils.copy(new StringReader(json), response.getOutputStream());
	}

	@RequestMapping(value = "/ui/saveOAISet.do", method = RequestMethod.POST)
	public void saveOAISet(final HttpServletResponse response,
			final HttpServletRequest request,
			@RequestParam(value = "setSpec", required = true) final String setSpec) throws Exception {

		log.info("setSpec = " + setSpec);
		SetInfo update = new Gson().fromJson(request.getReader(), SetInfo.class);
		log.info("Update to object" + update);
		boolean result = false;
		if (this.configuration.getSetInfo(setSpec) != null) {
			log.info("UPDATING set = " + setSpec);
			result = this.configurationWriter.updateOAISet(setSpec, update);
		} else {
			// ADD NEW mdf
			log.info("CREATING new OAIset = " + setSpec);
			result = this.configurationWriter.addOAISet(update);
		}
		response.getWriter().print(result);
	}

	@RequestMapping(value = "/ui/deleteOAISet.do")
	public void deleteOAISet(final HttpServletResponse response, @RequestParam(value = "setSpec", required = true) final String setSpec) throws Exception {
		boolean result = this.configurationWriter.deleteOAISet(setSpec);
		response.getWriter().print(result);
	}

	@RequestMapping(value = "/ui/showIndices.do")
	public void showIndices(final HttpServletResponse response,
			@RequestParam(value = "format", required = true) final String format,
			@RequestParam(value = "layout", required = true) final String layout,
			@RequestParam(value = "interpretation", required = true) final String interpretation) throws Exception {

		List<PublisherField> fields = this.configuration.getFields(format, interpretation, layout);

		// Need to iterate over the values to build an object otherwise angularjs does not allow me to edit the content!
		// See http://stackoverflow.com/questions/13714884/difficulty-with-ng-model-ng-repeat-and-inputs
		List<OAIIndex> indices = Lists.newArrayList();
		for (PublisherField field : fields) {
			Collection<String> paths = field.getSources().get(format + "-" + layout + "-" + interpretation);
			List<IndexPath> pathList = Lists.newArrayList();
			for (String p : paths) {
				pathList.add(new IndexPath(p));
			}
			OAIIndex idx = new OAIIndex();
			idx.setRepeatable(field.isRepeatable());
			idx.setName(field.getFieldName());
			idx.setPaths(pathList);
			indices.add(idx);
		}
		String json = new Gson().toJson(indices);
		log.info("The map of indices: " + json);
		IOUtils.copy(new StringReader(json), response.getOutputStream());
	}

	@RequestMapping(value = "/ui/saveIndices.do", method = RequestMethod.POST)
	public void saveIndices(final HttpServletResponse response,
			final HttpServletRequest request,
			@RequestParam(value = "format", required = true) final String format,
			@RequestParam(value = "layout", required = true) final String layout,
			@RequestParam(value = "interpretation", required = true) final String interpretation) throws Exception {

		StringWriter sw = new StringWriter();
		IOUtils.copy(request.getInputStream(), sw);
		Type collectionType = new TypeToken<List<OAIIndex>>() {}.getType();
		List<OAIIndex> indexes = new Gson().fromJson(sw.toString(), collectionType);
		final String mdformatKey = format + "-" + layout + "-" + interpretation;
		List<PublisherField> updatedIndices = Lists.transform(indexes, new Function<OAIIndex, PublisherField>() {

			@Override
			public PublisherField apply(final OAIIndex oaiIndex) {
				PublisherField f = new PublisherField();
				f.setFieldName(oaiIndex.getName());
				f.setRepeatable(oaiIndex.isRepeatable());
				Multimap<String, String> paths = ArrayListMultimap.create();
				for (IndexPath path : oaiIndex.getPaths()) {
					paths.put(mdformatKey, path.getPath());
				}
				f.setSources(paths);
				return f;
			}

		});

		log.info("Updating indices" + indexes);
		boolean result = this.configurationWriter.updateIndices(format, layout, interpretation, updatedIndices);
		response.getWriter().print(result);
	}

	@RequestMapping(value = "/ui/saveNewIndex.do")
	public void saveNewIndex(final HttpServletResponse response,
			@RequestParam(value = "format", required = true) final String format,
			@RequestParam(value = "layout", required = true) final String layout,
			@RequestParam(value = "interpretation", required = true) final String interpretation,
			@RequestParam(value = "indexName", required = true) final String indexName,
			@RequestParam(value = "repeatable", required = true) final boolean repeatable,
			@RequestParam(value = "paths", required = true) final String paths) throws Exception {

		String[] thePaths = paths.split(",");
		boolean result = this.configurationWriter.addNewIndex(format, layout, interpretation, indexName, repeatable, thePaths);
		response.getWriter().print(result);
	}

	@RequestMapping(value = "/ui/saveNewPathIndex.do")
	public void saveNewPathIndex(final HttpServletResponse response,
			@RequestParam(value = "format", required = true) final String format,
			@RequestParam(value = "layout", required = true) final String layout,
			@RequestParam(value = "interpretation", required = true) final String interpretation,
			@RequestParam(value = "indexName", required = true) final String indexName,
			@RequestParam(value = "newPath", required = true) final String newPath) throws Exception {

		List<PublisherField> fields = this.configurationWriter.getConfiguration().getFields(format, interpretation, layout);
		Iterable<PublisherField> updated = Iterables.transform(fields, new Function<PublisherField, PublisherField>() {

			@Override
			public PublisherField apply(final PublisherField field) {
				if (field.getFieldName().equals(indexName)) {
					field.getSources().get(format + "-" + layout + "-" + interpretation).add(newPath);
				}
				return field;
			}
		});
		boolean result = this.configurationWriter.updateIndices(format, layout, interpretation, Lists.newArrayList(updated));
		response.getWriter().print(result);
	}

	@RequestMapping(value = "/ui/getTransformationRules.do")
	public void getTransformationRules(final HttpServletResponse response) throws IOException {

		final String query = "for $x in collection('/db/DRIVER/TransformationRuleDSResources/TransformationRuleDSResourceType')"
				+ " return concat($x//RESOURCE_IDENTIFIER/@value/string(), ':-:', $x//CONFIGURATION//TITLE)";
		Iterable<TDSRule> rules = this.configuration.getQueryExecutor().query(TDSRule.class, query);
		String json = new Gson().toJson(Lists.newArrayList(rules));
		IOUtils.copy(new StringReader(json), response.getOutputStream());
	}

}
